@@ -21,8 +21,6 @@
 
 #include <pulsar/MessageId.h>
 
-#include <atomic>
-#include <cstdint>
 #include <mutex>
 #include <set>
 
@@ -35,9 +33,6 @@ class ClientImpl;
 using ClientImplPtr = std::shared_ptr<ClientImpl>;
 class ExecutorService;
 using ExecutorServicePtr = std::shared_ptr<ExecutorService>;
-class HandlerBase;
-using HandlerBasePtr = std::shared_ptr<HandlerBase>;
-using HandlerBaseWeakPtr = std::weak_ptr<HandlerBase>;
 
 /**
  * @class AckGroupingTrackerEnabled
@@ -45,35 +40,31 @@ using HandlerBaseWeakPtr = std::weak_ptr<HandlerBase>;
  */
 class AckGroupingTrackerEnabled : public AckGroupingTracker {
    public:
-    AckGroupingTrackerEnabled(std::function<ClientConnectionPtr()> connectionSupplier,
-                              std::function<uint64_t()> requestIdSupplier, uint64_t consumerId,
-                              bool waitResponse, long ackGroupingTimeMs, long ackGroupingMaxSize,
+    AckGroupingTrackerEnabled(long ackGroupingTimeMs, long ackGroupingMaxSize, bool waitResponse,
                               const ExecutorServicePtr& executor)
-        : AckGroupingTracker(connectionSupplier, requestIdSupplier, consumerId, waitResponse),
-          ackGroupingTimeMs_(ackGroupingTimeMs),
+        : ackGroupingTimeMs_(ackGroupingTimeMs),
           ackGroupingMaxSize_(ackGroupingMaxSize),
+          waitResponse_(waitResponse),
           executor_(executor) {
         pendingIndividualCallbacks_.reserve(ackGroupingMaxSize);
     }
 
-    virtual ~AckGroupingTrackerEnabled() { this->close(); }
+    ~AckGroupingTrackerEnabled();
 
-    void start() override;
+    void start(const ConsumerImplPtr& consumer) override;
     bool isDuplicate(const MessageId& msgId) override;
-    void addAcknowledge(const MessageId& msgId, ResultCallback callback) override;
-    void addAcknowledgeList(const MessageIdList& msgIds, ResultCallback callback) override;
-    void addAcknowledgeCumulative(const MessageId& msgId, ResultCallback callback) override;
-    void close() override;
-    void flush() override;
+    void addAcknowledge(const MessageId& msgId, const ResultCallback& callback) override;
+    void addAcknowledgeList(const MessageIdList& msgIds, const ResultCallback& callback) override;
+    void addAcknowledgeCumulative(const MessageId& msgId, const ResultCallback& callback) override;
     void flushAndClean() override;
+    void close() override;
+
+   private:
+    void flush(const ConsumerImplPtr& consumer);
 
    protected:
-    //! Method for scheduling grouping timer.
     void scheduleTimer();
 
-    //! State
-    std::atomic_bool isClosed_{false};
-
     //! Next message ID to be cumulatively cumulatively.
     MessageId nextCumulativeAckMsgId_{MessageId::earliest()};
     bool requireCumulativeAck_{false};
@@ -91,6 +82,8 @@ class AckGroupingTrackerEnabled : public AckGroupingTracker {
     //! Max number of ACK requests can be grouped.
     const long ackGroupingMaxSize_;
 
+    const bool waitResponse_;
+
     //! ACK request sender's scheduled executor.
     const ExecutorServicePtr executor_;
 
