@@ -19,6 +19,7 @@
 #include "ConsumerImpl.h"
 
 #include <pulsar/DeadLetterPolicyBuilder.h>
+#include <pulsar/EncryptionContext.h>
 #include <pulsar/MessageIdBuilder.h>
 
 #include <algorithm>
@@ -59,8 +60,7 @@ DECLARE_LOG_OBJECT()
 using std::chrono::milliseconds;
 using std::chrono::seconds;
 
-static boost::optional<MessageId> getStartMessageId(const boost::optional<MessageId>& startMessageId,
-                                                    bool inclusive) {
+static optional<MessageId> getStartMessageId(const optional<MessageId>& startMessageId, bool inclusive) {
     if (!inclusive || !startMessageId) {
         return startMessageId;
     }
@@ -69,7 +69,7 @@ static boost::optional<MessageId> getStartMessageId(const boost::optional<Messag
     auto chunkMsgIdImpl =
         dynamic_cast<const ChunkMessageIdImpl*>(Commands::getMessageIdImpl(startMessageId.value()).get());
     if (chunkMsgIdImpl) {
-        return boost::optional<MessageId>{chunkMsgIdImpl->getChunkedMessageIds().front()};
+        return optional<MessageId>{chunkMsgIdImpl->getChunkedMessageIds().front()};
     }
     return startMessageId;
 }
@@ -97,7 +97,7 @@ ConsumerImpl::ConsumerImpl(const ClientImplPtr& client, const std::string& topic
                            bool hasParent /* = false by default */,
                            const ConsumerTopicType consumerTopicType /* = NonPartitioned by default */,
                            Commands::SubscriptionMode subscriptionMode,
-                           const boost::optional<MessageId>& startMessageId)
+                           const optional<MessageId>& startMessageId)
     : ConsumerImplBase(
           client, topic,
           Backoff(milliseconds(client->getClientConfig().getInitialBackoffIntervalMs()),
@@ -243,7 +243,7 @@ Future<Result, bool> ConsumerImpl::connectionOpened(const ClientConnectionPtr& c
     Lock lockForMessageId(mutexForMessageId_);
     clearReceiveQueue();
     const auto subscribeMessageId =
-        (subscriptionMode_ == Commands::SubscriptionModeNonDurable) ? startMessageId_.get() : boost::none;
+        (subscriptionMode_ == Commands::SubscriptionModeNonDurable) ? startMessageId_.get() : std::nullopt;
     lockForMessageId.unlock();
 
     unAckedMessageTrackerPtr_->clear();
@@ -433,7 +433,7 @@ void ConsumerImpl::discardChunkMessages(const std::string& uuid, const MessageId
 
 void ConsumerImpl::triggerCheckExpiredChunkedTimer() {
     checkExpiredChunkedTimer_->expires_after(milliseconds(expireTimeOfIncompleteChunkedMessageMs_));
-    std::weak_ptr<ConsumerImplBase> weakSelf{shared_from_this()};
+    auto weakSelf = weak_from_this();
     checkExpiredChunkedTimer_->async_wait([this, weakSelf](const ASIO_ERROR& ec) -> void {
         auto self = weakSelf.lock();
         if (!self) {
@@ -464,11 +464,11 @@ void ConsumerImpl::triggerCheckExpiredChunkedTimer() {
     });
 }
 
-boost::optional<SharedBuffer> ConsumerImpl::processMessageChunk(const SharedBuffer& payload,
-                                                                const proto::MessageMetadata& metadata,
-                                                                const proto::MessageIdData& messageIdData,
-                                                                const ClientConnectionPtr& cnx,
-                                                                MessageId& messageId) {
+optional<SharedBuffer> ConsumerImpl::processMessageChunk(const SharedBuffer& payload,
+                                                         const proto::MessageMetadata& metadata,
+                                                         const proto::MessageIdData& messageIdData,
+                                                         const ClientConnectionPtr& cnx,
+                                                         MessageId& messageId) {
     const auto chunkId = metadata.chunk_id();
     const auto& uuid = metadata.uuid();
     LOG_DEBUG("Process message chunk (chunkId: " << chunkId << ", uuid: " << uuid
@@ -521,14 +521,14 @@ boost::optional<SharedBuffer> ConsumerImpl::processMessageChunk(const SharedBuff
         lock.unlock();
         increaseAvailablePermits(cnx);
         trackMessage(messageId);
-        return boost::none;
+        return {};
     }
 
     chunkedMsgCtx.appendChunk(messageId, payload);
     if (!chunkedMsgCtx.isCompleted()) {
         lock.unlock();
         increaseAvailablePermits(cnx);
-        return boost::none;
+        return {};
     }
 
     messageId = std::make_shared<ChunkMessageIdImpl>(chunkedMsgCtx.moveChunkedMessageIds())->build();
@@ -541,7 +541,7 @@ boost::optional<SharedBuffer> ConsumerImpl::processMessageChunk(const SharedBuff
     if (uncompressMessageIfNeeded(cnx, messageIdData, metadata, wholePayload, false)) {
         return wholePayload;
     } else {
-        return boost::none;
+        return {};
     }
 }
 
@@ -550,24 +550,27 @@ void ConsumerImpl::messageReceived(const ClientConnectionPtr& cnx, const proto::
                                    proto::MessageMetadata& metadata, SharedBuffer& payload) {
     LOG_DEBUG(getName() << "Received Message -- Size: " << payload.readableBytes());
 
-    if (!decryptMessageIfNeeded(cnx, msg, metadata, payload)) {
-        // Message was discarded or not consumed due to decryption failure
-        return;
-    }
-
     if (!isChecksumValid) {
         // Message discarded for checksum error
         discardCorruptedMessage(cnx, msg.message_id(), CommandAck_ValidationError_ChecksumMismatch);
         return;
     }
 
-    auto redeliveryCount = msg.redelivery_count();
-    const bool isMessageUndecryptable =
-        metadata.encryption_keys_size() > 0 && !config_.getCryptoKeyReader().get() &&
-        config_.getCryptoFailureAction() == ConsumerCryptoFailureAction::CONSUME;
+    auto encryptionContext = metadata.encryption_keys_size() > 0
+                                 ? optional<EncryptionContext>(std::in_place, metadata, false)
+                                 : std::nullopt;
+    const auto decryptionResult = decryptMessageIfNeeded(cnx, msg, encryptionContext, payload);
+    if (decryptionResult == DecryptionResult::FAILED) {
+        // Message was discarded or not consumed due to decryption failure
+        return;
+    } else if (decryptionResult == DecryptionResult::CONSUME_ENCRYPTED && encryptionContext.has_value()) {
+        // Message is encrypted, but we let the application consume it as-is
+        encryptionContext->setDecryptionFailed(true);
+    }
 
+    auto redeliveryCount = msg.redelivery_count();
     const bool isChunkedMessage = metadata.num_chunks_from_msg() > 1;
-    if (!isMessageUndecryptable && !isChunkedMessage) {
+    if (decryptionResult == DecryptionResult::SUCCESS && !isChunkedMessage) {
         if (!uncompressMessageIfNeeded(cnx, msg.message_id(), metadata, payload, true)) {
             // Message was discarded on decompression error
             return;
@@ -591,6 +594,7 @@ void ConsumerImpl::messageReceived(const ClientConnectionPtr& cnx, const proto::
     m.impl_->cnx_ = cnx.get();
     m.impl_->setTopicName(getTopicPtr());
     m.impl_->setRedeliveryCount(msg.redelivery_count());
+    m.impl_->encryptionContext_ = std::move(encryptionContext);
 
     if (metadata.has_schema_version()) {
         m.impl_->setSchemaVersion(metadata.schema_version());
@@ -611,7 +615,7 @@ void ConsumerImpl::messageReceived(const ClientConnectionPtr& cnx, const proto::
         return;
     }
 
-    if (metadata.has_num_messages_in_batch()) {
+    if (metadata.has_num_messages_in_batch() && decryptionResult == DecryptionResult::SUCCESS) {
         BitSet::Data words(msg.ack_set_size());
         for (int i = 0; i < words.size(); i++) {
             words[i] = msg.ack_set(i);
@@ -813,17 +817,18 @@ uint32_t ConsumerImpl::receiveIndividualMessagesFromBatch(const ClientConnection
     return batchSize - skippedMessages;
 }
 
-bool ConsumerImpl::decryptMessageIfNeeded(const ClientConnectionPtr& cnx, const proto::CommandMessage& msg,
-                                          const proto::MessageMetadata& metadata, SharedBuffer& payload) {
-    if (!metadata.encryption_keys_size()) {
-        return true;
+auto ConsumerImpl::decryptMessageIfNeeded(const ClientConnectionPtr& cnx, const proto::CommandMessage& msg,
+                                          const optional<EncryptionContext>& context, SharedBuffer& payload)
+    -> DecryptionResult {
+    if (!context.has_value()) {
+        return DecryptionResult::SUCCESS;
     }
 
     // If KeyReader is not configured throw exception based on config param
     if (!config_.isEncryptionEnabled()) {
         if (config_.getCryptoFailureAction() == ConsumerCryptoFailureAction::CONSUME) {
             LOG_WARN(getName() << "CryptoKeyReader is not implemented. Consuming encrypted message.");
-            return true;
+            return DecryptionResult::CONSUME_ENCRYPTED;
         } else if (config_.getCryptoFailureAction() == ConsumerCryptoFailureAction::DISCARD) {
             LOG_WARN(getName() << "Skipping decryption since CryptoKeyReader is not implemented and config "
                                   "is set to discard");
@@ -834,20 +839,20 @@ bool ConsumerImpl::decryptMessageIfNeeded(const ClientConnectionPtr& cnx, const
             auto messageId = MessageIdBuilder::from(msg.message_id()).build();
             unAckedMessageTrackerPtr_->add(messageId);
         }
-        return false;
+        return DecryptionResult::FAILED;
     }
 
     SharedBuffer decryptedPayload;
-    if (msgCrypto_->decrypt(metadata, payload, config_.getCryptoKeyReader(), decryptedPayload)) {
+    if (msgCrypto_->decrypt(*context, payload, config_.getCryptoKeyReader(), decryptedPayload)) {
         payload = decryptedPayload;
-        return true;
+        return DecryptionResult::SUCCESS;
     }
 
     if (config_.getCryptoFailureAction() == ConsumerCryptoFailureAction::CONSUME) {
         // Note, batch message will fail to consume even if config is set to consume
         LOG_WARN(
             getName() << "Decryption failed. Consuming encrypted message since config is set to consume.");
-        return true;
+        return DecryptionResult::CONSUME_ENCRYPTED;
     } else if (config_.getCryptoFailureAction() == ConsumerCryptoFailureAction::DISCARD) {
         LOG_WARN(getName() << "Discarding message since decryption failed and config is set to discard");
         discardCorruptedMessage(cnx, msg.message_id(), CommandAck_ValidationError_DecryptionError);
@@ -856,7 +861,7 @@ bool ConsumerImpl::decryptMessageIfNeeded(const ClientConnectionPtr& cnx, const
         auto messageId = MessageIdBuilder::from(msg.message_id()).build();
         unAckedMessageTrackerPtr_->add(messageId);
     }
-    return false;
+    return DecryptionResult::FAILED;
 }
 
 bool ConsumerImpl::uncompressMessageIfNeeded(const ClientConnectionPtr& cnx,
@@ -1124,7 +1129,7 @@ void ConsumerImpl::clearReceiveQueue() {
         if (hasSoughtByTimestamp()) {
             // Invalidate startMessageId_ so that isPriorBatchIndex and isPriorEntryIndex checks will be
             // skipped, and hasMessageAvailableAsync won't use startMessageId_ in compare.
-            startMessageId_ = boost::none;
+            startMessageId_ = std::nullopt;
         } else {
             startMessageId_ = seekMessageId_.get();
         }
@@ -1313,11 +1318,11 @@ void ConsumerImpl::negativeAcknowledge(const MessageId& messageId) {
     negativeAcksTracker_->add(messageId);
 }
 
-void ConsumerImpl::disconnectConsumer() { disconnectConsumer(boost::none); }
+void ConsumerImpl::disconnectConsumer() { disconnectConsumer(std::nullopt); }
 
-void ConsumerImpl::disconnectConsumer(const boost::optional<std::string>& assignedBrokerUrl) {
+void ConsumerImpl::disconnectConsumer(const optional<std::string>& assignedBrokerUrl) {
     LOG_INFO("Broker notification of Closed consumer: "
-             << consumerId_ << (assignedBrokerUrl ? (" assignedBrokerUrl: " + assignedBrokerUrl.get()) : ""));
+             << consumerId_ << (assignedBrokerUrl ? (" assignedBrokerUrl: " + *assignedBrokerUrl) : ""));
     resetCnx();
     scheduleReconnection(assignedBrokerUrl);
 }
@@ -1745,7 +1750,7 @@ void ConsumerImpl::seekAsyncInternal(long requestId, const SharedBuffer& seek, c
     seekCallback_ = callback;
     LOG_INFO(getName() << " Seeking subscription to " << seekArg);
 
-    std::weak_ptr<ConsumerImpl> weakSelf{get_shared_this_ptr()};
+    auto weakSelf = weak_from_this();
 
     cnx->sendRequestWithId(seek, requestId)
         .addListener([this, weakSelf, callback, originalSeekMessageId](Result result,
@@ -1851,9 +1856,9 @@ void ConsumerImpl::processPossibleToDLQ(const MessageId& messageId, const Proces
     }
 
     for (const auto& message : messages.value()) {
-        std::weak_ptr<ConsumerImpl> weakSelf{get_shared_this_ptr()};
-        deadLetterProducer_->getFuture().addListener([weakSelf, message, messageId, cb](Result res,
-                                                                                        Producer producer) {
+        auto weakSelf = weak_from_this();
+        deadLetterProducer_->getFuture().addListener([this, weakSelf, message, messageId, cb](
+                                                         Result res, Producer producer) {
             auto self = weakSelf.lock();
             if (!self) {
                 return;
@@ -1872,30 +1877,29 @@ void ConsumerImpl::processPossibleToDLQ(const MessageId& messageId, const Proces
             if (message.hasOrderingKey()) {
                 msgBuilder.setOrderingKey(message.getOrderingKey());
             }
-            producer.sendAsync(msgBuilder.build(), [weakSelf, originMessageId, messageId, cb](
+            producer.sendAsync(msgBuilder.build(), [this, weakSelf, originMessageId, messageId, cb](
                                                        Result res, const MessageId& messageIdInDLQ) {
                 auto self = weakSelf.lock();
                 if (!self) {
                     return;
                 }
                 if (res == ResultOk) {
-                    if (self->state_ != Ready) {
+                    if (state_ != Ready) {
                         LOG_WARN(
                             "Send to the DLQ successfully, but consumer is not ready. ignore acknowledge : "
-                            << self->state_);
+                            << state_);
                         cb(false);
                         return;
                     }
-                    self->possibleSendToDeadLetterTopicMessages_.remove(messageId);
-                    self->acknowledgeAsync(originMessageId, [weakSelf, originMessageId, cb](Result result) {
+                    possibleSendToDeadLetterTopicMessages_.remove(messageId);
+                    acknowledgeAsync(originMessageId, [this, weakSelf, originMessageId, cb](Result result) {
                         auto self = weakSelf.lock();
                         if (!self) {
                             return;
                         }
                         if (result != ResultOk) {
-                            LOG_WARN("{" << self->topic() << "} {" << self->subscription_ << "} {"
-                                         << self->getConsumerName() << "} Failed to acknowledge the message {"
-                                         << originMessageId
+                            LOG_WARN("{" << topic() << "} {" << subscription_ << "} {" << getConsumerName()
+                                         << "} Failed to acknowledge the message {" << originMessageId
                                          << "} of the original topic but send to the DLQ successfully : "
                                          << result);
                             cb(false);
@@ -1906,9 +1910,9 @@ void ConsumerImpl::processPossibleToDLQ(const MessageId& messageId, const Proces
                         }
                     });
                 } else {
-                    LOG_WARN("{" << self->topic() << "} {" << self->subscription_ << "} {"
-                                 << self->getConsumerName() << "} Failed to send DLQ message to {"
-                                 << self->deadLetterPolicy_.getDeadLetterTopic() << "} for message id "
+                    LOG_WARN("{" << topic() << "} {" << subscription_ << "} {" << getConsumerName()
+                                 << "} Failed to send DLQ message to {"
+                                 << deadLetterPolicy_.getDeadLetterTopic() << "} for message id "
                                  << "{" << originMessageId << "} : " << res);
                     cb(false);
                 }
