@@ -88,7 +88,10 @@ void MessageImpl::setTopicName(const std::shared_ptr<std::string>& topicName) {
     messageId.setTopicName(topicName);
 }
 
-const std::string& MessageImpl::getTopicName() { return *topicName_; }
+const std::string& MessageImpl::getTopicName() {
+    static const std::string emptyString = "";
+    return topicName_ ? *topicName_ : emptyString;
+}
 
 int MessageImpl::getRedeliveryCount() { return redeliveryCount_; }
 
@@ -122,7 +125,7 @@ void MessageImpl::convertPayloadToKeyValue(const pulsar::SchemaInfo& schemaInfo)
                                        getKeyValueEncodingType(schemaInfo));
 }
 
-KeyValueEncodingType MessageImpl::getKeyValueEncodingType(SchemaInfo schemaInfo) {
+KeyValueEncodingType MessageImpl::getKeyValueEncodingType(const SchemaInfo& schemaInfo) {
     if (schemaInfo.getSchemaType() != KEY_VALUE) {
         throw std::invalid_argument("Schema not key value type.");
     }
