@@ -110,7 +110,7 @@ ProducerStatsImpl::~ProducerStatsImpl() { cancelTimer(*timer_); }
 
 void ProducerStatsImpl::scheduleTimer() {
     timer_->expires_after(std::chrono::seconds(statsIntervalInSeconds_));
-    std::weak_ptr<ProducerStatsImpl> weakSelf{shared_from_this()};
+    auto weakSelf = weak_from_this();
     timer_->async_wait([this, weakSelf](const ASIO_ERROR& ec) {
         auto self = weakSelf.lock();
         if (!self) {
